//  Copyright 2019 Kakao Corp.
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.

import UIKit

//MARK: - SelectableCollectionViewCell
class SelectableCollectionViewCell: UICollectionViewCell {
    var titleLabel: UILabel = {
        let label = UILabel(frame: CGRect.zero)

        return label
    }()
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        titleLabel.font = UIFont.systemFont(ofSize: CommonConstants.paramCollectionViewCellFontSize, weight: .regular)
        titleLabel.backgroundColor = UIColor.init(white: 1.0, alpha: 0)
        titleLabel.textAlignment = .center
        titleLabel.textColor = UIColor.black
        titleLabel.adjustsFontSizeToFitWidth = true
        
        contentView.backgroundColor = UIColor.init(red: 0.1, green: 0.1, blue: 0.1, alpha: 0.1)
        contentView.addSubview(titleLabel)
        
        addSubviewsConstraint()
    }
    
    required init?(coder aDecoder: NSCoder) {
        fatalError("Never will happen")
    }
    
    func addSubviewsConstraint() {        
        titleLabel.translatesAutoresizingMaskIntoConstraints = false
        titleLabel.centerYAnchor.constraint(equalTo: contentView.centerYAnchor).isActive = true
        titleLabel.heightAnchor.constraint(equalTo: contentView.heightAnchor).isActive = true
        titleLabel.widthAnchor.constraint(equalTo: contentView.widthAnchor).isActive = true
    }
    
    override func layoutSubviews() {
        super.layoutSubviews()
    }

    override func prepareForReuse() {
        super.prepareForReuse()
    }
    
    func updateCollectionViewCellUI(selected:Bool) {
        setSelected(selected)
    }
    
    func setSelected(_ cellSelected:Bool) {
        if cellSelected {
            titleLabel.textColor = UIColor.white
            self.contentView.backgroundColor = UIColor.init(red: 0.1, green: 0.1, blue: 0.1, alpha: 0.9)
        } else {
            titleLabel.textColor = UIColor.black
            self.contentView.backgroundColor = UIColor.init(red: 0.1, green: 0.1, blue: 0.1, alpha: 0.1)
        }
    }
}

